package com.aucma.base.service.impl;

import java.util.List;

import com.aucma.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.base.mapper.BaseOrderInfoMapper;
import com.aucma.base.domain.BaseOrderInfo;
import com.aucma.base.service.IBaseOrderInfoService;

/**
 * 工单信息Service业务层处理
 *
 * @author Yinq
 * @date 2023-09-27
 */
@Service
public class BaseOrderInfoServiceImpl implements IBaseOrderInfoService {
    @Autowired
    private BaseOrderInfoMapper baseOrderInfoMapper;

    /**
     * 查询工单信息
     *
     * @param objId 工单信息主键
     * @return 工单信息
     */
    @Override
    public BaseOrderInfo selectBaseOrderInfoByObjId(Long objId) {
        return baseOrderInfoMapper.selectBaseOrderInfoByObjId(objId);
    }

    /**
     * 查询工单信息列表
     *
     * @param baseOrderInfo 工单信息
     * @return 工单信息
     */
    @Override
    public List<BaseOrderInfo> selectBaseOrderInfoList(BaseOrderInfo baseOrderInfo) {
        return baseOrderInfoMapper.selectBaseOrderInfoList(baseOrderInfo);
    }

    /**
     * 新增工单信息
     *
     * @param baseOrderInfo 工单信息
     * @return 结果
     */
    @Override
    public int insertBaseOrderInfo(BaseOrderInfo baseOrderInfo) {
        baseOrderInfo.setCreatedTime(DateUtils.getNowDate());
        return baseOrderInfoMapper.insertBaseOrderInfo(baseOrderInfo);
    }

    /**
     * 修改工单信息
     *
     * @param baseOrderInfo 工单信息
     * @return 结果
     */
    @Override
    public int updateBaseOrderInfo(BaseOrderInfo baseOrderInfo) {
        baseOrderInfo.setUpdatedTime(DateUtils.getNowDate());
        return baseOrderInfoMapper.updateBaseOrderInfo(baseOrderInfo);
    }

    /**
     * 批量删除工单信息
     *
     * @param objIds 需要删除的工单信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseOrderInfoByObjIds(Long[] objIds) {
        return baseOrderInfoMapper.deleteBaseOrderInfoByObjIds(objIds);
    }

    /**
     * 删除工单信息信息
     *
     * @param objId 工单信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseOrderInfoByObjId(Long objId) {
        return baseOrderInfoMapper.deleteBaseOrderInfoByObjId(objId);
    }
}
